aboutsummaryrefslogtreecommitdiff
path: root/tests/json.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/json.c')
-rw-r--r--tests/json.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/json.c b/tests/json.c
index 0166c1a..a213302 100644
--- a/tests/json.c
+++ b/tests/json.c
@@ -1,4 +1,4 @@
/* grecs - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it
@@ -23,8 +23,8 @@
#include <string.h>
#include <errno.h>
#include <stdlib.h>
-#include "grecs.h"
-#include "grecs/json.h"
+#include "argot.h"
+#include "argot/json.h"
static void
printer(void *d, char const *buf, size_t size)
@@ -90,7 +90,7 @@ main(int argc, char **argv)
size = (size_t) st.st_size;
if (size != st.st_size)
abort();
- input = grecs_malloc(size + 1);
+ input = argot_malloc(size + 1);
n = read(fd, input, size);
if (n == -1) {
perror("read");
@@ -115,7 +115,7 @@ main(int argc, char **argv)
if (!obj) {
json_err_locus.beg.file = json_err_locus.end.file =
file ? file : "input";
- grecs_error(&json_err_locus, 0, "%s", json_err_diag);
+ argot_error(&json_err_locus, 0, "%s", json_err_diag);
return 3;
}
if (key) {
@@ -1,4 +1,4 @@
-/* grecs - Gray's Extensible Configuration System
+/* argot - Gray's Extensible Configuration System
Copyright (C) 2007-2016 Sergey Poznyakoff
Grecs is free software; you can redistribute it and/or modify it

Return to:

Send suggestions and report system problems to the System administrator.